@@ -23,7 +23,6 @@ LLM_API_HOSTS = {
 }
 LLM_TEMPERATURE = float(os.getenv("LLM_TEMPERATURE", "0.1"))
 LLM_TOP_P = float(os.getenv("LLM_TOP_P", "0.5"))
-LLM_NO_THINK = os.getenv("LLM_NO_THINK", "false").lower() == "true"
 
 # Common Analysis Configuration
 RESPONSE_LANGUAGE = os.getenv("RESPONSE_LANGUAGE", "korean")
@@ -32,17 +31,15 @@ ANALYSIS_MODE = os.getenv("ANALYSIS_MODE", "batch")
 # Log Paths Configuration
 LOG_PATHS = {
     "httpd_access": os.getenv("LOG_PATH_HTTPD_ACCESS", "sample-logs/access-10k.log"),
-    "httpd_apache_error": os.getenv("LOG_PATH_HTTPD_APACHE_ERROR", "sample-logs/apache-10k.log"),
-    "linux_system": os.getenv("LOG_PATH_LINUX_SYSTEM", "sample-logs/linux-2k.log"),
-    "tcpdump_packet": os.getenv("LOG_PATH_TCPDUMP_PACKET", "sample-logs/tcpdump-packet-2k.log")
+    "httpd_server": os.getenv("LOG_PATH_HTTPD_SERVER", "sample-logs/apache-10k.log"),
+    "linux_system": os.getenv("LOG_PATH_LINUX_SYSTEM", "sample-logs/linux-2k.log")
 }
 
-# Real-time Log Paths Configuration
-REALTIME_LOG_PATHS = {
+# Realtime log paths configuration 
+LOG_PATHS_REALTIME = {
     "httpd_access": os.getenv("LOG_PATH_REALTIME_HTTPD_ACCESS", "/var/log/apache2/access.log"),
-    "httpd_apache_error": os.getenv("LOG_PATH_REALTIME_HTTPD_APACHE_ERROR", "/var/log/apache2/error.log"),
-    "linux_system": os.getenv("LOG_PATH_REALTIME_LINUX_SYSTEM", "/var/log/messages"),
-    "tcpdump_packet": os.getenv("LOG_PATH_REALTIME_TCPDUMP_PACKET", "/var/log/tcpdump.log")
+    "httpd_server": os.getenv("LOG_PATH_REALTIME_HTTPD_SERVER", "/var/log/apache2/error.log"),
+    "linux_system": os.getenv("LOG_PATH_REALTIME_LINUX_SYSTEM", "/var/log/messages")
 }
 
 # Real-time Monitoring Configuration
@@ -66,20 +63,18 @@ DEFAULT_REMOTE_SSH_CONFIG = {
     "timeout": int(os.getenv("REMOTE_SSH_TIMEOUT", "10"))
 }
 
-# Default Remote Log Paths Configuration
+# Remote SSH configuration for log paths
 DEFAULT_REMOTE_LOG_PATHS = {
     "httpd_access": os.getenv("REMOTE_LOG_PATH_HTTPD_ACCESS", "/var/log/apache2/access.log"),
-    "httpd_apache_error": os.getenv("REMOTE_LOG_PATH_HTTPD_APACHE_ERROR", "/var/log/apache2/error.log"),
-    "linux_system": os.getenv("REMOTE_LOG_PATH_LINUX_SYSTEM", "/var/log/messages"),
-    "tcpdump_packet": os.getenv("REMOTE_LOG_PATH_TCPDUMP_PACKET", "/var/log/tcpdump.log")
+    "httpd_server": os.getenv("REMOTE_LOG_PATH_HTTPD_SERVER", "/var/log/apache2/error.log"),
+    "linux_system": os.getenv("REMOTE_LOG_PATH_LINUX_SYSTEM", "/var/log/messages")
 }
 
 # Default Chunk Sizes
 LOG_CHUNK_SIZES = {
     "httpd_access": int(os.getenv("CHUNK_SIZE_HTTPD_ACCESS", "10")),
-    "httpd_apache_error": int(os.getenv("CHUNK_SIZE_HTTPD_APACHE_ERROR", "10")),
-    "linux_system": int(os.getenv("CHUNK_SIZE_LINUX_SYSTEM", "10")),
-    "tcpdump_packet": int(os.getenv("CHUNK_SIZE_TCPDUMP_PACKET", "5"))
+    "httpd_server": int(os.getenv("CHUNK_SIZE_HTTPD_SERVER", "10")),
+    "linux_system": int(os.getenv("CHUNK_SIZE_LINUX_SYSTEM", "10"))
 }
 
 # GeoIP Configuration
@@ -103,7 +98,7 @@ def get_analysis_config(log_type, chunk_size=None, analysis_mode=None,
     Get analysis configuration for specific log type
     
     Args:
-        log_type: Log type ("httpd_access", "httpd_apache_error", "linux_system", "tcpdump_packet")
+        log_type: Log type ("httpd_access", "httpd_server", "linux_system")
         chunk_size: Override chunk size (optional)
         analysis_mode: Override analysis mode (optional) - "batch" or "realtime"
         remote_mode: Override remote mode (optional) - "local" or "ssh" 
@@ -120,7 +115,7 @@ def get_analysis_config(log_type, chunk_size=None, analysis_mode=None,
     if access_mode == "ssh":
         log_path = remote_log_path or DEFAULT_REMOTE_LOG_PATHS.get(log_type, "")
     else:
-        log_path = REALTIME_LOG_PATHS.get(log_type, "") if mode == "realtime" else LOG_PATHS.get(log_type, "")
+        log_path = LOG_PATHS_REALTIME.get(log_type, "") if mode == "realtime" else LOG_PATHS.get(log_type, "")
     
     # SSH configuration
     if access_mode == "ssh":
@@ -146,7 +141,7 @@ def get_llm_config(llm_provider=None):
         llm_provider: LLM provider name (optional, defaults to global LLM_PROVIDER)
     
     Returns:
-        dict: Configuration containing provider, model, api_host, temperature, top_p, no_think
+        dict: Configuration containing provider, model, api_host, temperature, top_p
     """
     provider = llm_provider if llm_provider is not None else LLM_PROVIDER
     
@@ -155,6 +150,5 @@ def get_llm_config(llm_provider=None):
         "model": LLM_MODELS.get(provider, "unknown"),
         "api_host": LLM_API_HOSTS.get(provider, ""),
         "temperature": LLM_TEMPERATURE,
-        "top_p": LLM_TOP_P,
-        "no_think": LLM_NO_THINK
+        "top_p": LLM_TOP_P
     }
